$wnd.rstudio.runAsyncCallback17("function Adt(a){this.a=a}\nfunction cpt(a){this.a=a}\nfunction ept(a,b){this.a=a;this.b=b}\nfunction A2u(a,b){this.a=a;this.b=b}\nfunction W2u(a,b){this.a=a;this.b=b}\nfunction Bhw(a,b){Ahw();this.b=a;this.a=b}\nfunction qkt(a,b){Yit();var c;c=a;SQu(c,b.a)}\nfunction f0v(a,b){K5j(a.w,b)}\nfunction KQu(a,b){f0v(a.vb,b)}\nfunction Obt(a){ldi(a.o,a.c,null)}\nfunction Pbt(a){ldi(a.o,a.g,null)}\nfunction uct(a){Lct(a.p,a.g,r1z,null)}\nfunction Bct(a){Lct(a.p,a.g,'prev',null)}\nfunction zct(a){Lct(a.p,a.g,'next',null)}\nfunction Cct(a){Lct(a.p,a.g,'refresh',null)}\nfunction Qbt(a){ldi(a.o,a.g+'?print-pdf',null)}\nfunction n8i(a){return {items:a}}\nfunction DQu(a,b){en((Zm(),Ym),new W2u(a,b))}\nfunction pkt(a,b){Yit();en((Zm(),Ym),new ept(b,a))}\nfunction WFh(a){$wnd.desktop.setPresentationUrl(a)}\nfunction K5j(a,b){a.d.navigateToPresentationEditorLocation(b)}\nfunction SQu(a,b){tlw(a.A,NJy,false)?_Ou(a,new A2u(a,b)):z7u(a.ab,b)}\nfunction Ibt(a,b){oue(b.substr(0,4),WNx)||(b=j7l(a.q,b));return b}\nfunction Nbt(a){!!a.b&&qQh(a.n,new Bhw(def(a.b.source_file),h8i(a.d,a.a,a.e)),false)}\nfunction i8i(a,b){var c,d,e,f;b==-1&&(b=a.auto_slide_level);f=g8i(a,b,true);for(c=0;c<f.length;c++){e=f[c];for(d=0;d<e.items.length;d++){if(oue(e.items[d].type,_ny))return c}}return 0}\nfunction h8i(a,b,c){var d,e,f,g,h;c==-1&&(c=b.auto_slide_level);h=g8i(b,c,false);if(a<h.length){g=h[a];zl(g.items,k8i(g.items[0].row))}e=[];for(d=0;d<h.length;d++){g=h[d];for(f=0;f<g.items.length;f++){xl(e,g.items[f])}}return j8i(e,b.auto_slide_level)}\nfunction z7u(a,b){var c,d,e,f,g,h,i;e=y7u(a).items;d=[];for(g=0;g<e.length;g++){h=e[g];oue(h.type,_ny)||(d[d.length]=h,undefined)}c=-1;i=b.items;for(f=0;f<i.length;f++){if(oue(i[f].type,_ny)){c=f;break}}if(c>=0){h=d[c];!!h&&aeu(a.a,znw(h.row,0),true)}}\nfunction g8i(a,b,c){var d,e,f,g,h,i;i=[];g=a.items;for(d=0;d<g.length;d++){f=g[d];e=i.length==0||oue(f.type,oLx)||oue(f.type,'hr')||oue(f.type,NKx)&&f.level<=b;if(e){h=n8i([]);xl(h.items,f);i[i.length]=h}else (c||!oue(f.type,_ny))&&xl(i[i.length-1].items,f)}return i}\nfunction Rbt(a,b){var c,d;c=b.a;d=Ibt(a,c.url);a.p=i8i(b.a.editor_state,b.a.slide_level);a.p==0&&a.d!=0&&(a.p=a.d);lZp(a.k);if(!oue(d,a.g)||!a.k.p){a.g=d;a.c=d;a.b=c.quarto_navigation;a.a=c.editor_state;a.e=c.slide_level;(YEh()||!!$wnd.remoteDesktop)&&WFh(a.g);yct(a.k,a.g,a.b)}else{Cct(a.k)}}\nfunction yct(a,b,c){var d;(YEh()||!!$wnd.remoteDesktop)&&(cZe(b)?(Oh(a.d).removeAttribute(Rny),undefined):(Oh(a.d).setAttribute(Rny,h0A),undefined));a.b=b;a.p=null;a.g=null;d=Qh(a.d);d>0&&yi(a,new Abf(eO(d*0.6666666666666666)+((a.L?Ph(a.L):0)+(a.P?Ph(a.P):0))));QHg(a.d,a.b);c.is_website?L_l(a.j):K_l(a.j,c.source_file,c.output_file);f9g(a.q)}\nfunction wdt(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=_dt(a.a.b.a);vTp(a.a,a.a.a)}switch(a.c){case 1:a.a.a.K.Z4b();break;case 2:a.a.a.K.$4b();break;case 3:Nbt(a.a.a);break;case 4:uct(a.a.a.k);break;case 5:zct(a.a.a.k);break;case 6:Obt(a.a.a);break;case 7:Pbt(a.a.a);break;case 8:Bct(a.a.a.k);break;case 9:Qbt(a.a.a);break;case 10:Rbt(a.a.a,a.b[0]);break;case 11:Cct(a.a.a.k);break;case 12:a.a.a.K._4b();break;case 13:a.a.a.K.a5b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nTFd(300,1,Wwy);_.kn=function zdt(){wdt((new Adt(this)).a)};TFd(7234,1,uZx,Adt);_.mn=function Bdt(){wdt(this.a)};var EKc=Ese(7234);TFd(3190,1,pZx,cpt);_.kw=function dpt(a){pkt(this.a,a)};var wOc=Ese(3190);TFd(3189,1,RLx,ept);_.mn=function fpt(){qkt(this.a,this.b)};var xOc=Ese(3189);TFd(4927,1,uZx,A2u);_.mn=function B2u(){DQu(this.a,this.b)};var q2c=Ese(4927);TFd(4926,1,RLx,W2u);_.mn=function X2u(){KQu(this.a,this.b)};var B2c=Ese(4926);TFd(3239,ANx,{},Bhw);_.$n=function Chw(a){var b,c;b=(c=hQi(a.n,this.b),!!c&&ZN(c,78)?c:(bQi(),XPi));ctt(a.b,this.b,b,new cpt(this))};_.ao=function Ehw(){return zhw};_._n=function Dhw(){return zhw};var xjd=Ese(3239);qJx(fm)(17);\n//# sourceURL=rstudio-17.js\n")
